from functools import wraps
import logging

from pydantic import ValidationError
from requests import HTTPError


from trailblazer.exc import ResponseDeserializationError, SlurmAPIClientError

LOG = logging.getLogger(__name__)


def handle_errors(func):
    @wraps(func)
    def wrapper(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except HTTPError as e:
            LOG.error(f"Error for request in slurm API client: {e.response.content}")
            raise SlurmAPIClientError()
        except ValidationError as e:
            LOG.error(f"Error deserializing slurm API response: {e}")
            raise ResponseDeserializationError()

    return wrapper



from trailblazer.clients.tower.models import TowerTask
from trailblazer.store.models import Job


def create_job_from_tower_task(task: TowerTask) -> Job:
    return Job(
        slurm_id=task.nativeId,
        name=task.process,
        status=task.status,
        started_at=task.start,
        elapsed=int(task.duration / 60),
    )
